unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, TaskSched, ComCtrls;

type
  TForm1 = class(TForm)
    Button1: TButton;
    ListView1: TListView;
    Button2: TButton;
    ListView2: TListView;
    Label1: TLabel;
    Button3: TButton;
    Button4: TButton;
    Button5: TButton;
    Button6: TButton;
    Button7: TButton;
    Label2: TLabel;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ListView1SelectItem(Sender: TObject; Item: TListItem;
      Selected: Boolean);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure Button5Click(Sender: TObject);
    procedure Button6Click(Sender: TObject);
    procedure Button7Click(Sender: TObject);
  private
    { Private declarations }
  public
    Sched : TTaskScheduler;
    procedure RefreshTaskList;
    procedure RefreshTriggerList(TaskName : String);
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.RefreshTaskList;
var
  I : Integer;
  Item : TListItem;
  Time : TDateTime;
begin
  ListView1.Items.Clear;

  for I := 0 to sched.Tasks.Count - 1 do
  begin
    Item := ListView1.Items.Add;
    Item.Caption := sched.Tasks[I].Name;
    Item.Checked := Sched.Tasks[I].Enabled;
    Item.SubItems.Add(sched.Tasks[I].AppName);
    Time := sched.Tasks[I].GetNextRunTime;

    if Time = 0 then
      Item.SubItems.Add('No start time')
    else
      Item.SubItems.Add(DateTimeToStr(Time));

    Item.SubItems.Add(sched.Tasks[I].Parameters);
  end;
end;

procedure TForm1.RefreshTriggerList(TaskName : String);
var
  N : Integer;
  AItem : TListItem;
  Trigger : TTaskSchedulerTaskTrigger;
begin
  ListView2.Items.Clear;

  for N := 0 to Sched.Tasks[TaskName].Triggers.Count - 1 do
  begin
    Trigger := Sched.Tasks[TaskName].Triggers[N];

    AItem := ListView2.Items.Add;
    AItem.Checked := Trigger.Enabled;
    AItem.Caption := Trigger.Description;
    AItem.SubItems.Add(DateTimeToStr(Trigger.StartTime));

    if Trigger.HasEndDate then
      AItem.SubItems.Add(DateTimeToStr(Trigger.StopTime))
    else
      AItem.SubItems.Add('');

    if Trigger.Kind = tskWeekly then
      AItem.SubItems.Add(Trigger.GetDaysOfWeekStr);

    if Trigger.Kind in [tskMonthlyDayOfWeek, tskMonthlyDate] then
      AItem.SubItems.Add(Trigger.GetMonthsStr);

    if Trigger.Kind in [tskDaily] then
      AItem.SubItems.Add(IntToStr(Trigger.DaysInterval) + ' days');

    if Trigger.Kind in [tskMonthlyDate] then
      AItem.SubItems.Add(Trigger.GetDaysOfMonthStr + ' day of ' + Trigger.GetMonthsStr);
  end;
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  RefreshTaskList;
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  if ListView1.Selected = nil then Exit;

  with Sched.tasks[ListView1.Selected.Caption] do
  begin
    Parameters := 'POOOOOOP';
    AppName := 'c:\schnrub.exe';
   end;

  RefreshTaskList;
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  sched := TTaskScheduler.Create;
  RefreshTaskList;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  sched.Free;
  sched := nil;
end;

procedure TForm1.ListView1SelectItem(Sender: TObject; Item: TListItem;
  Selected: Boolean);
begin
  Button3.Enabled := Selected;
  ListView2.Items.Clear;
  if Selected then RefreshTriggerList(Item.Caption);
end;

procedure TForm1.Button3Click(Sender: TObject);
begin
  Sched.Tasks[ListView1.Selected.Caption].Edit;
end;

procedure TForm1.Button4Click(Sender: TObject);
var
  I : Integer;
  Trigger : TTaskSchedulerTaskTrigger;
  ListItem : TListItem;
begin
  if (ListView1.Selected = nil) or (ListView2.Selected = nil) then Exit;

  I := ListView2.Selected.Index;
  Trigger := Sched.Tasks[ListView1.Selected.Caption].Triggers[I];

  Trigger.DaysInterval := 4;
  Trigger.Save;

  ListItem := ListView1.Selected;
  ListView1.Selected := Nil;
  ListView1.Selected := ListItem;
end;

procedure TForm1.Button5Click(Sender: TObject);
var
  Trigger : TTaskSchedulerTaskTrigger;
begin
  if (ListView1.Selected = nil) then Exit;
  Trigger := Sched.Tasks[ListView1.Selected.Caption].Triggers.Add;
  Trigger.StartTime := Now;
  Trigger.Kind := tskDaily;
  Trigger.DaysInterval := 1;
  Trigger.Save;

  RefreshTriggerList(ListView1.Selected.Caption);
end;

procedure TForm1.Button6Click(Sender: TObject);
var
  Task : TTaskSchedulerTask;
  Trigger : TTaskSchedulerTaskTrigger;
begin
  Task := Sched.Tasks.Add('My pointless task');
  Task.AppName := 'c:\windows\command.com';
  Trigger := Task.Triggers.Add;
  Trigger.HasEndDate := False;
  Trigger.Kind := tskMonthlyDate;
  Trigger.DaysOfMonth := TaskSchedulerDayToDaysOfMonth(27);
  Trigger.Months := [tsmJanuary, tsmFebruary, tsmJuly];
  Trigger.StartTime := Now;
  Trigger.Enabled := True;
  Trigger.Save;

  RefreshTaskList;
end;

procedure TForm1.Button7Click(Sender: TObject);
begin
  if (ListView1.Selected = nil) then Exit;
  Sched.Tasks.Delete(ListView1.Selected.Caption);

  RefreshTaskList;
end;

end.
